import { useState } from "react";
import { Search, X } from "react-feather";
import useMessagesStore from "@/feature/messenger/store/chat_store/useMessagesStore";
import { Button, Tooltip } from "@nextui-org/react";
import { useTranslation } from "@/src/hooks/useTranslation";


const SearchChat = ({search,setSearch}: any) => {

    //state
    const setSearchListMessages = useMessagesStore(state => state.actions.setSearchListMessages);
    const { trans } = useTranslation();

    //const [search, setSearch] = useState(false);
    const [searchMessage, setSearchMessage] = useState('');

    const handlerSeacrhMessages = (event: any) => {
        event.preventDefault();
        const searchValue = event.target.value;
        setSearchMessage(searchValue);
        setSearchListMessages({ type: 'message', value: searchValue });
    }

    const handlerCloseSearch = () => {
        setSearch(false);
        setSearchMessage('');
        setSearchListMessages({ type: 'message', value: '' });
    }

    return (
        <>
            <Tooltip
                placement="right"
                content={trans('header_content_chat_button_title')}	
                color="default"
            >
                <Button color="default" className={`${search ? "hidden" : "visible"} size-10 min-h-10 min-w-10 p-0 md:m-3 md:mr-0 bg-transparent text-indigo-500`} radius="full" onClick={() => setSearch(!search)} variant="flat">
                    <Search size={20} />
                </Button>
            </Tooltip>
            <div className={`py-1 sm:py-2 flex flex-row items-center w-full transition ease-in-out delay-150 duration-300 relative`}>
                <div className={`w-full flex flex-row justify-center items-center px-5 ${search ? "visible" : "hidden"}`}>
                    <label htmlFor="simple-search" className="sr-only">Search</label>
                    <div className="relative w-full">
                        <div className="absolute inset-y-0 start-0 flex items-center ps-3 pointer-events-none">
                            <Search className="text-gray-500" size={20} />
                        </div>
                        <input type="text" value={searchMessage} onChange={handlerSeacrhMessages} onKeyDown={(e) => { e.key === 'Enter' && e.preventDefault(); }} className="focus:outline-none focus:ring-0 focus:border-transparent bg-gray-100 border border-gray-200 text-gray-900 text-sm rounded-lg block w-full ps-10 p-2.5  dark:bg-gray-700 dark:border-gray-600 dark:placeholder-gray-400 dark:text-white" placeholder={trans('header_content_chat_search_placeholder')} />
                        <button onClick={() => handlerCloseSearch()} type="button" className={`absolute top-0 end-0 p-2.5 h-full text-sm font-medium text-white bg-gray-100 focus:outline-none focus:ring-blue-300 dark:bg-gray-700 border-gray-600 border-1`} >
                            <Tooltip
                                placement="left"
                                content={trans('search_close_text')}	
                                color="default"
                            >
                                <X className="text-gray-500 cursor-pointer hover:text-gray-950 dark:text-white" size={20} />
                            </Tooltip>
                        </button>
                    </div>
                </div>
            </div>
        </>
    )
}


export default SearchChat;